@@ -137,15 +137,21 @@ def printEquationsSolution(eq, solution, printEq=True):
 
 def solveSimultaneousEqs(eq):
     '''
+    Solve Simultaneous Equations
+    Finite solutions only. No expression based answers.
+
     Usage:
     eq = list()
     eq.append("-x/10-x/5-6-(x-y)/2")
     eq.append("y/4-3-6-(x-y)/2")
     solveSimultaneousEqs(eq)
     '''
-    # Sympy Review https://docs.sympy.org/latest/modules/solvers/solvers.html
 
     eq = [sympify(expr) for expr in eq]
+    # for k,v in subsDict.items():
+    #     # exec(f"{k}=symbols('{sym.name}')")
+    #     eq.append()
+
     freesym = [expr.free_symbols for expr in eq]
     freevar = list()
     for freeset in freesym:
@@ -159,12 +165,10 @@ def solveSimultaneousEqs(eq):
     solutionList = list()
     for possibility in solutions:
         solutionList.append(dict(zip(freevar,possibility)))
-        # print((dict(zip(freevar,possibility))))
         return solutionList
-    # pass
 
 if __name__ == "__main__":
     eq = list()
-    eq.append("Eq(-x/10-x/5-6-(x-y)/2,0)")
-    eq.append("y/4-3-6-(x-y)/2")
+    eq.append("Eq(-v1/10-v1/5-6-(v1-v2)/2,0)")
+    eq.append("v2/4-3-6-(v1-v2)/2")
     print(solveSimultaneousEqs(eq))
\ No newline at end of file
